@@ -20,6 +20,7 @@ KGlobalAccelImpl *KGlobalAccelImpl::instance()
 KGlobalAccelImpl::KGlobalAccelImpl(QObject *parent)
     : KGlobalAccelInterface(parent)
 {
+    s_interface = this;
 }
 
 KGlobalAccelImpl::~KGlobalAccelImpl()
@@ -33,19 +34,9 @@ bool KGlobalAccelImpl::grabKey(int keyQt, bool grab)
     return true;
 }
 
-void KGlobalAccelImpl::setEnabled(bool enable)
+bool KGlobalAccelImpl::checkKeyEvent(int keyQt, ShortcutKeyState state)
 {
-    s_interface = enable ? this : nullptr;
-}
-
-bool KGlobalAccelImpl::checkKeyPressed(int keyQt)
-{
-    return keyPressed(keyQt);
-}
-
-bool KGlobalAccelImpl::checkKeyReleased(int keyQt)
-{
-    return keyReleased(keyQt);
+    return keyEvent(keyQt, state);
 }
 
 bool KGlobalAccelImpl::checkPointerPressed(Qt::MouseButtons button)
