@@ -8,7 +8,7 @@
 
 #include "kserviceactioncomponent.h"
 #include "globalshortcutcontext.h"
-#include "logging_p.h"
+#include "logging.h"
 
 #include <QFileInfo>
 
@@ -45,16 +45,20 @@ QString makeUniqueName(const KService::Ptr &service)
     return service->storageId();
 }
 
-KServiceActionComponent::KServiceActionComponent(KService::Ptr service)
-    : Component(makeUniqueName(service), service->name())
+KServiceActionComponent::KServiceActionComponent(KService::Ptr service, GlobalShortcutsRegistry *registry)
+    : Component(makeUniqueName(service), service->name(), registry)
     , m_service(service)
 {
 }
 
 KServiceActionComponent::~KServiceActionComponent() = default;
 
-void KServiceActionComponent::emitGlobalShortcutPressed(const GlobalShortcut &shortcut)
+void KServiceActionComponent::emitGlobalShortcutEvent(const GlobalShortcut &shortcut, ShortcutKeyState state)
 {
+    if (state != ShortcutKeyState::Pressed) {
+        return;
+    }
+
     KIO::ApplicationLauncherJob *job = nullptr;
 
     if (shortcut.uniqueName() == QLatin1String("_launch")) {
@@ -151,7 +155,7 @@ void KServiceActionComponent::writeSettings(KConfigGroup &config) const
     }
 }
 
-void KServiceActionComponent::loadSettings(KConfigGroup &configGroup)
+void KServiceActionComponent::loadSettings(const KConfigGroup &configGroup)
 {
     // Action shortcuts
     const auto actions = m_service->actions();
